@@ -153,11 +153,11 @@
 				},
 				formatResult: function (element) {
 					if (element.type === "createPublicRoom") {
-						return '<span><div class="avatar icon-public-white"></div>' + escapeHTML(element.displayName) + '</span>';
+						return '<span><div class="avatar icon-public"></div>' + escapeHTML(element.displayName) + '</span>';
 					}
 
 					if (element.type === "createGroupRoom" || element.type === 'group') {
-						return '<span><div class="avatar icon-contacts"></div>' + escapeHTML(element.displayName) + '</span>';
+						return '<span><div class="avatar icon-contacts-dark"></div>' + escapeHTML(element.displayName) + '</span>';
 					}
 
 					return '<span><div class="avatar" data-user="' + escapeHTML(element.id) + '" data-user-display-name="' + escapeHTML(element.displayName) + '"></div>' + escapeHTML(element.displayName) + '</span>';
@@ -553,6 +553,28 @@
 				$('#emptycontent').show();
 			});
 
+			this.listenTo(roomChannel, 'joinRoom', function(token) {
+				if (OCA.Talk.PublicShareAuth) {
+					return;
+				}
+
+				if (this._popingState) {
+					return;
+				}
+
+				OC.Util.History.pushState({
+					token: token
+				}, OC.generateUrl('/call/' + token));
+			});
+
+			this.listenTo(roomChannel, 'leaveCurrentRoom', function() {
+				if (OCA.Talk.PublicShareAuth) {
+					return;
+				}
+
+				OC.Util.History.replaceState({}, OC.generateUrl('/apps/spreed'));
+			});
+
 			this._mediaControlsView = new OCA.SpreedMe.Views.MediaControlsView({
 				app: this,
 				webrtc: OCA.SpreedMe.webrtc,
@@ -662,7 +684,9 @@
 		},
 		_onPopState: function(params) {
 			if (!_.isUndefined(params.token)) {
+				this._popingState = true;
 				this.connection.joinRoom(params.token);
+				delete this._popingState;
 			}
 		},
 		onDocumentClick: function(event) {
