@@ -74,6 +74,7 @@
 		this.features = {};
 		this.pendingChatRequests = [];
 		this._lastChatMessagesFetch = null;
+		this.chatBatchSize = 100;
 	}
 
 	OCA.Talk.Signaling.Base = Base;
@@ -362,6 +363,7 @@
 	OCA.Talk.Signaling.Base.prototype._getChatRequestData = function(lastKnownMessageId) {
 		return {
 			lastKnownMessageId: lastKnownMessageId,
+			limit: this.chatBatchSize,
 			lookIntoFuture: 1
 		};
 	};
@@ -430,7 +432,9 @@
 
 		this._waitTimeUntilRetry = 1;
 
-		if (this.receiveMessagesAgain) {
+		// Fetch more messages if PHP backend or a whole batch has been received
+		// (more messages might be available in this case).
+		if (this.receiveMessagesAgain || (messages && messages.length === this.chatBatchSize)) {
 			this._receiveChatMessages();
 		}
 
@@ -540,8 +544,11 @@
 		this._startPullingMessages();
 	};
 
-	OCA.Talk.Signaling.Internal.prototype._doLeaveRoom = function(/*token*/) {
-		// Nothing to do anymore
+	OCA.Talk.Signaling.Internal.prototype._doLeaveRoom = function(token) {
+		if (token === this.currentRoomToken && !this.roomCollection) {
+			window.clearInterval(this.roomPoller);
+			this.roomPoller = null;
+		}
 	};
 
 	OCA.Talk.Signaling.Internal.prototype.sendCallMessage = function(data) {
@@ -601,6 +608,7 @@
 			success: function (result) {
 				this.pullMessagesFails = 0;
 				$.each(result.ocs.data, function(id, message) {
+					this._trigger('onBeforeReceiveMessage', [message]);
 					switch(message.type) {
 						case "usersInRoom":
 							this._trigger('usersInRoom', [message.data]);
@@ -616,6 +624,7 @@
 							console.log('Unknown Signaling Message');
 							break;
 					}
+					this._trigger('onAfterReceiveMessage', [message]);
 				}.bind(this));
 				this._startPullingMessages();
 			}.bind(this),
@@ -624,7 +633,7 @@
 					// Request has been aborted. Ignore.
 				} else if (this.currentRoomToken) {
 					if (this.pullMessagesFails >= 3) {
-						OCA.SpreedMe.app.connection.leaveCurrentRoom(false);
+						OCA.SpreedMe.app.connection.leaveCurrentRoom();
 						return;
 					}
 
@@ -747,6 +756,7 @@
 					delete this.callbacks[id];
 				cb(data);
 			}
+			this._trigger('onBeforeReceiveMessage', [data]);
 			switch (data.type) {
 				case "hello":
 					if (!id) {
@@ -777,6 +787,7 @@
 					}
 					break;
 			}
+			this._trigger('onAfterReceiveMessage', [data]);
 		}.bind(this);
 	};
 
