@@ -44,6 +44,7 @@ OC.L10N.register(
     "Share link" : "Dela länk",
     "Change password" : "Byt lösenord",
     "Set password" : "Sätt lösenord",
+    "Go to file" : "Gå till fil",
     "Name" : "Namn",
     "Conversation name" : "Konversationens namn",
     "Rename" : "Byt namn",
@@ -119,6 +120,7 @@ OC.L10N.register(
     "Show screen" : "Visa skärm",
     "Enable video" : "Aktivera video",
     "Access to microphone & camera is only possible with HTTPS" : "Tillgång till mikrofon och kamera är endast möjligt via HTTPS",
+    "Please move your setup to HTTPS" : "Vänligen flytta din inställning till HTTPS",
     "Access to microphone & camera was denied" : "Tillgång till mikrofon och kamera blev nekad",
     "WebRTC is not supported in your browser" : "WebRTC är inte kompatibelt med din webbläsare",
     "Error while accessing microphone & camera" : "Kunde ej ansluta mikrofon och kamera",
