@@ -266,7 +266,10 @@ class Application extends App {
 			$notifier = $this->getBackendNotifier();
 
 			$room = $event->getSubject();
-			$notifier->participantsModified($room);
+			// TODO: The list of removed session ids should be passed through the event
+			// so the signaling server can optimize forwarding the message.
+			$sessionIds = [];
+			$notifier->participantsModified($room, $sessionIds);
 		});
 		$dispatcher->addListener(GuestManager::class . '::updateName', function(GenericEvent $event) {
 			/** @var BackendNotifier $notifier */
@@ -353,6 +356,16 @@ class Application extends App {
 			$notificationHooks->generateInvitation($room, $event->getArgument('users'));
 		};
 		$dispatcher->addListener(Room::class . '::postAddUsers', $listener);
+
+		$listener = function(GenericEvent $event) {
+			/** @var Room $room */
+			$room = $event->getSubject();
+
+			/** @var \OCA\Spreed\Notification\Hooks $notificationHooks */
+			$notificationHooks = $this->getContainer()->query(\OCA\Spreed\Notification\Hooks::class);
+			$notificationHooks->markInvitationRead($room);
+		};
+		$dispatcher->addListener(Room::class . '::postJoinRoom', $listener);
 	}
 
 	protected function registerCallNotificationHook(EventDispatcherInterface $dispatcher) {
@@ -365,6 +378,16 @@ class Application extends App {
 			$notificationHooks->generateCallNotifications($room);
 		};
 		$dispatcher->addListener(Room::class . '::preSessionJoinCall', $listener);
+
+		$listener = function(GenericEvent $event) {
+			/** @var Room $room */
+			$room = $event->getSubject();
+
+			/** @var \OCA\Spreed\Notification\Hooks $notificationHooks */
+			$notificationHooks = $this->getContainer()->query(\OCA\Spreed\Notification\Hooks::class);
+			$notificationHooks->markCallNotificationsRead($room);
+		};
+		$dispatcher->addListener(Room::class . '::postSessionJoinCall', $listener);
 	}
 
 	protected function registerChatHooks(EventDispatcherInterface $dispatcher) {
